@@ -1,24 +1,7 @@
-# The MIT License (MIT)
+# SPDX-FileCopyrightText: 2017 Tony DiCola for Adafruit Industries
 #
-# Copyright (c) 2017 Tony DiCola for Adafruit Industries
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
+# SPDX-License-Identifier: MIT
+
 """
 `adafruit_fxos8700`
 ====================================================
@@ -57,7 +40,6 @@ __version__ = "0.0.0-auto.0"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_FXOS8700.git"
 
 # Register addresses and other constants:
-# pylint: disable=bad-whitespace
 _FXOS8700_ADDRESS = const(0x1F)  # 0011111
 _FXOS8700_ID = const(0xC7)  # 1100 0111
 _FXOS8700_REGISTER_STATUS = const(0x00)
@@ -89,7 +71,6 @@ _ACCEL_MG_LSB_4G = 0.000488
 _ACCEL_MG_LSB_8G = 0.000976
 _MAG_UT_LSB = 0.1
 _SENSORS_GRAVITY_STANDARD = 9.80665
-# pylint: enable=bad-whitespace
 
 # User-facing constants/module-level globals:
 ACCEL_RANGE_2G = 0x00
@@ -190,7 +171,7 @@ class FXOS8700:
     @property
     def accelerometer(self):
         """Read the acceleration from the accelerometer and return its X, Y, Z axis values as a
-           3-tuple in m/s^2.
+        3-tuple in m/s^2.
         """
         accel_raw, _ = self.read_raw_accel_mag()
         # Convert accel values to m/s^2
@@ -205,7 +186,8 @@ class FXOS8700:
 
     @property
     def magnetometer(self):
-        """Read the magnetometer values and return its X, Y, Z axis values as a 3-tuple in uTeslas.
+        """
+        Read the magnetometer values and return its X, Y, Z axis values as a 3-tuple in uTeslas.
         """
         _, mag_raw = self.read_raw_accel_mag()
         # Convert mag values to uTesla
